==> bitcoin-0.21.1.knots20210629.tar.gz: bitcoin-0.21.1.knots20210629/src/qt/locale/bitcoin_no.ts <==
<TS language="no" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Lag en ny adresse</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Ny
</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopier den valgte adressen til systemutklippstavlen</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopier</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>C&amp;Tap</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Slett den valgte adressen fra listen </translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Tast inn adressen eller etiketten for å søke</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Eksporter dataen i gjeldende fane til en fil </translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksporter</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Slett</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Velg adressen du vil sende mynter til </translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Velg adressen du vil motta mynter med </translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Sender adresser </translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Mottar adresser </translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Dette er dine Bitcoin adresser for å sende betalinger.Alltid sjekk mengden og mottaker adressen før du sender mynter.  </translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Koper adresse</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Eksporter adresse liste</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Eksportering feilet </translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Address</source>
        <translation>Adresse </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;Sender adresser </translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;Mottar adresser </translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>&amp;Copy address</source>
        <translation>&amp;Koper adresse</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;Adresse </translation>
    </message>
    </context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>Adresse </translation>
    </message>
</context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">CTap</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer</extracomment>
        <translation>&amp;Koper adresse</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Copy address</source>
        <translation>&amp;Koper adresse</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished">Adresse :</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation type="unfinished">&amp;Koper adresse</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>&amp;Copy address</source>
        <translation>&amp;Koper adresse</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse </translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Eksportering feilet </translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksporter</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Eksporter dataen i gjeldende fane til en fil </translation>
    </message>
    </context>
</TS>

==> bitcoin-21.2.knots20210629.tar.gz: bitcoin-21.2.knots20210629/src/qt/locale/bitcoin_no.ts <==
<TS language="no" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Lag en ny adresse</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Ny
</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopier den valgte adressen til systemutklippstavlen</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopier</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>C&amp;Tap</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Slett den valgte adressen fra listen </translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Tast inn adressen eller etiketten for å søke</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Eksporter dataen i gjeldende fane til en fil </translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksporter</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Slett</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Velg adressen du vil sende mynter til </translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Velg adressen du vil motta mynter med </translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Sender adresser </translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Mottar adresser </translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Dette er dine Bitcoin adresser for å sende betalinger.Alltid sjekk mengden og mottaker adressen før du sender mynter.  </translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Koper adresse</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Eksporter adresse liste</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Eksportering feilet </translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Address</source>
        <translation>Adresse </translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;Sender adresser </translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;Mottar adresser </translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>&amp;Copy address</source>
        <translation>&amp;Koper adresse</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;Adresse </translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>Adresse </translation>
    </message>
</context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">CTap</translation>
    </message>
    </context>
<context>
    <name>PairingPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer</extracomment>
        <translation>&amp;Koper adresse</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Copy address</source>
        <translation>&amp;Koper adresse</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished">Adresse :</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation type="unfinished">&amp;Koper adresse</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>&amp;Copy address</source>
        <translation>&amp;Koper adresse</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse </translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Eksportering feilet </translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksporter</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Eksporter dataen i gjeldende fane til en fil </translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>
